@@ -50,10 +50,11 @@ module Internals
     1258 => "WINDOWS-1258", #(Vietnamese)
     1361 => "WINDOWS-1361", #(Korean (Johab))
     10000 => "MACROMAN",
+    21010 => "UTF-16LE",
     32768 => "MACROMAN",
     32769 => "WINDOWS-1252", #(Latin I) (BIFF2-BIFF3)
   }
-  SEGAPEDOC = CODEPAGES.invert
+  SEGAPEDOC = CODEPAGES.reject { |k, _v| k >= 21010 }.invert
   # color_codes according to http://support.softartisans.com/kbview_1205.aspx
   # synonyms are in comments when reverse lookup
   COLOR_CODES = {
