@@ -56,7 +56,7 @@ class Reader
       ## remove two bits
       integer, = work.unpack 'V'
       integer &= 0xfffffffc
-      value, = ("\0\0\0\0" << [integer].pack('V')).unpack EIGHT_BYTE_DOUBLE
+      value, = ("\0\0\0\0" +  [integer].pack('V')).unpack EIGHT_BYTE_DOUBLE
     else
       ## I can't find a format for unpacking a little endian signed integer.
       #  'V' works for packing, but not for unpacking. But the following works
@@ -125,11 +125,12 @@ class Reader
      #So link the noteObject(text) to the note (with author, position)
      #TODO
      @noteList.each do |i|
-        matching_obj = @noteObjList.select {|j| j.objID == i.objID}
-        if matching_obj.length > 1
+        matching_objs = @noteObjList.select { |j| j.objID == i.objID }
+        if matching_objs.length > 1
            puts "ERROR - more than one matching object ID!"
         end
-        i.text = matching_obj.first.text
+        matching_obj = matching_objs.first
+        i.text = matching_obj.nil? ? '' : matching_obj.text
         worksheet.add_note i.row, i.col, i.text
      end
   end
@@ -398,10 +399,10 @@ class Reader
       end
       formula.value = value
     elsif rtype == 0
-      pos, op, len, work = get_next_chunk
+      pos, op, _len, work = get_next_chunk
       if op == :sharedfmla
         ## TODO: formula-support in 0.8.0
-        pos, op, len, work = get_next_chunk
+        pos, op, _len, work = get_next_chunk
       end
       if op == :string
         formula.value = client read_string(work, 2), @workbook.encoding
@@ -851,6 +852,7 @@ class Reader
     @detected_rows = {}
     @noteObjList = []
     @noteList = []
+    @noteObject = nil
     previous = nil
     while tuple = get_next_chunk
       pos, op, len, work = tuple
@@ -1273,11 +1275,11 @@ class Reader
   end
   def setup io
     ## Reading from StringIO fails without forced encoding
-    if io.respond_to?(:string) && (str = io.string) \
-      && str.respond_to?(:force_encoding)
-      str.force_encoding 'ASCII-8BIT'
+    if Gem::Version.new(RUBY_VERSION) >= Gem::Version.new('2.3.0')
+      io.set_encoding('ASCII-8BIT')
+    elsif io.respond_to?(:string) && (str = io.string) && str.respond_to?(:force_encoding)
+      str.force_encoding('ASCII-8BIT')
     end
-    ##
     io.rewind
     @ole = Ole::Storage.open io
     @workbook = Workbook.new io, {}
