@@ -3,6 +3,7 @@ require 'spreadsheet/excel/writer/biff8'
 require 'spreadsheet/excel/internals'
 require 'spreadsheet/excel/internals/biff8'
 require 'bigdecimal'
+require 'rational' #for Ruby 1.8.x
 
 module Spreadsheet
   module Excel
@@ -19,7 +20,7 @@ class Worksheet
   def initialize workbook, worksheet
     @workbook = workbook
     @worksheet = worksheet
-    @io = StringIO.new ''
+    @io = StringIO.new ''.dup
     @biff_version = 0x0600
     @bof = 0x0809
     @build_id = 3515
@@ -64,7 +65,7 @@ class Worksheet
     cent = 0
     int = 2
     higher = value * 100
-    if (higher.is_a?(BigDecimal) or higher.is_a?(Float)) && higher < 0xfffffffc
+    if (higher.is_a?(Rational) or higher.is_a?(BigDecimal) or higher.is_a?(Float)) && higher < 0xfffffffc
       cent = 1
       if higher == higher.to_i
         value = higher.to_i
@@ -90,7 +91,7 @@ class Worksheet
   def need_number? cell
     if cell.is_a?(Numeric) && cell.abs > 0x1fffffff
       true
-    elsif (cell.is_a?(BigDecimal) or cell.is_a?(Float)) and not cell.nan?
+    elsif cell.is_a?(Rational) or ((cell.is_a?(BigDecimal) or cell.is_a?(Float)) and not cell.nan?)
       higher = cell * 100
       if higher == higher.to_i
         need_number? higher.to_i
@@ -242,84 +243,6 @@ class Worksheet
     end
     write_multiples row, first_idx, multiples if multiples
   end
-  def write_changes reader, endpos, sst_status
-
-    ## FIXME this is not smart solution to update outline_level.
-    #        without this process, outlines in row disappear in MS Excel.
-    @worksheet.row_count.times do |i|
-      if @worksheet.row(i).outline_level > 0
-        @worksheet.row(i).outline_level = @worksheet.row(i).outline_level
-      end
-    end
-
-    reader.seek @worksheet.offset
-    blocks = row_blocks
-    lastpos = reader.pos
-    offsets = {}
-    row_offsets = []
-    changes = @worksheet.changes
-    @worksheet.offsets.each do |key, pair|
-      if changes.include?(key) \
-        || (sst_status == :complete_update && key.is_a?(Integer))
-        offsets.store pair, key
-      end
-    end
-    ## FIXME it may be smarter to simply write all rowblocks, instead of doing a
-    #        song-and-dance routine for every row...
-    work = offsets.invert
-    work.each do |key, (pos, len)|
-      case key
-      when Integer
-        row_offsets.push [key, [pos, len]]
-      when :dimensions
-        row_offsets.push [-1, [pos, len]]
-      end
-    end
-    row_offsets.sort!
-    row_offsets.reverse!
-    control = changes.size
-    @worksheet.each do |row|
-      key = row.idx
-      if changes.include?(key) && !work.include?(key)
-        row, pair = row_offsets.find do |idx, _| idx <= key end
-        work.store key, pair
-      end
-    end
-    if changes.size > control
-      warn <<-EOS
-Your Worksheet was modified while it was being written. This should not happen.
-Please contact the author (hannes dot wyss at gmail dot com) with a sample file
-and minimal code that generates this warning. Thanks!
-      EOS
-    end
-    work = work.sort_by do |key, (pos, _)|
-      [pos, key.is_a?(Integer) ? key : -1]
-    end
-    work.each do |key, (pos, len)|
-      @io.write reader.read(pos - lastpos) if pos > lastpos
-      if key.is_a?(Integer)
-        if block = blocks.find do |rows| rows.any? do |row| row.idx == key end end
-          write_rowblock block
-          blocks.delete block
-        end
-      else
-        send "write_#{key}"
-      end
-      lastpos = pos + len
-      reader.seek lastpos
-    end
-
-    # Necessary for outline (grouping) and hiding functions
-    # but these below are not necessary to run
-    # if [Row|Column]#hidden? = false and [Row|Column]#outline_level == 0
-    write_merged_cells
-    write_pagesetup
-    write_margins
-    write_colinfos
-    write_guts
-
-    @io.write reader.read(endpos - lastpos)
-  end
   def write_colinfo bunch
     col = bunch.first
     width = col.width.to_f * 256
@@ -641,7 +564,7 @@ and minimal code that generates this warning. Thanks!
   ##
   # Write multiple consecutive cells with RK values (see #write_rk)
   def write_mulrk row, idx, multiples
-    fmt = 'v2'
+    fmt = ['v2']
     data = [
       row.idx, # Index to row
       idx, # Index to first column (fc)
@@ -654,7 +577,7 @@ and minimal code that generates this warning. Thanks!
     end
     # Index to last column (lc)
     data.push idx + multiples.size - 1
-    write_op opcode(:mulrk), data.pack(fmt << 'v')
+    write_op opcode(:mulrk), data.pack((fmt << 'v').join)
   end
   def write_multiples row, idx, multiples
     case multiples.last
@@ -847,8 +770,28 @@ and minimal code that generates this warning. Thanks!
     end
     flags |= 0x0080 # Show outline symbols,
                     # but if [Row|Column]#outline_level = 0 the symbols are not shown.
+    
+    if @worksheet.has_frozen_panel?
+      # See:
+      # OpenOffice.org's Documentation of the Microsoft Excel File FormatExcel 
+      # Versions 2, 3, 4, 5, 95, 97, 2000, XP, 2003
+      # https://www.openoffice.org/sc/excelfileformat.pdf
+      # section 5.110.2
+      flags |= 0x0008 #Panes are frozen (freeze)
+    end
     data = [ flags, 0, 0, 0, 0, 0 ].pack binfmt(:window2)
+        
     write_op opcode(:window2), data
+    if @worksheet.has_frozen_panel?
+      # See:
+      # OpenOffice.org's Documentation of the Microsoft Excel File FormatExcel 
+      # Versions 2, 3, 4, 5, 95, 97, 2000, XP, 2003
+      # https://www.openoffice.org/sc/excelfileformat.pdf
+      # section 5.75
+      pane_data = [@worksheet.froze_left, @worksheet.froze_top, @worksheet.froze_top, @worksheet.froze_left, 3].pack binfmt(:colinfo)
+      write_op opcode(:pane), pane_data
+    end
+    
   end
 
   def write_merged_cells
