@@ -19,8 +19,14 @@ module Spreadsheet
       assert_equal true, @format.date?
       @format.number_format = "YMD"
       assert_equal true, @format.date?
+      @format.number_format = "[$-409]YMD"
+      assert_equal true, @format.date?
       @format.number_format = "\\$#,##0.00_);[RED]\"($\"#,##0.00\\)"
       assert_equal false, @format.date?
+      @format.number_format = "0.00;[RED]\\-0.00"
+      assert_equal false, @format.date?
+      @format.number_format = "[$-C0A]dd\\-mmm\\-yy"
+      assert_equal true, @format.date?
     end
     def test_date_or_time?
       assert_equal false, @format.date_or_time?
@@ -30,8 +36,12 @@ module Spreadsheet
       assert_equal true, @format.date_or_time?
       @format.number_format = "hmsYMD"
       assert_equal true, @format.date_or_time?
+      @format.number_format = "[$-409]hmsYMD"
+      assert_equal true, @format.date_or_time?
       @format.number_format = "\\$#,##0.00_);[RED]\"($\"#,##0.00\\)"
-      assert_equal false, @format.date?
+      assert_equal false, @format.date_or_time?
+      @format.number_format = "0.00;[RED]\\-0.00)"
+      assert_equal false, @format.date_or_time?
     end
     def test_datetime?
       assert_equal false, @format.datetime?
@@ -44,7 +54,9 @@ module Spreadsheet
       @format.number_format = "HSYMD"
       assert_equal true, @format.datetime?
       @format.number_format = "\\$#,##0.00_);[RED]\"($\"#,##0.00\\)"
-      assert_equal false, @format.date?
+      assert_equal false, @format.datetime?
+      @format.number_format = "0.00;[RED]\\-0.00)"
+      assert_equal false, @format.datetime?
     end
     def test_time?
       assert_equal false, @format.time?
@@ -56,10 +68,14 @@ module Spreadsheet
       assert_equal true, @format.time?
       @format.number_format = "hm"
       assert_equal true, @format.time?
+      @format.number_format = "[$-409]hms"
+      assert_equal true, @format.time?
       @format.number_format = "hms"
       assert_equal true, @format.time?
       @format.number_format = "\\$#,##0.00_);[RED]\"($\"#,##0.00\\)"
-      assert_equal false, @format.date?
+      assert_equal false, @format.time?
+      @format.number_format = "0.00;[RED]\\-0.00)"
+      assert_equal false, @format.time?
     end
 		def test_borders?
 			assert_equal [:none, :none, :none, :none], @format.border
